SdpMatrix

Type Alias SdpMatrix 

pub type SdpMatrix = SdpMatrix2<f32>;
A 2D symmetric-definite-positive matrix.

Aliased Type

pub struct SdpMatrix {
    pub m11: f32,
    pub m12: f32,
    pub m22: f32,
}

Fields

m11: f32

The component at the first row and first column of this matrix.

m12: f32

The component at the first row and second column of this matrix.

m22: f32

The component at the second row and second column of this matrix.