SpatialVector

Type Alias SpatialVector 

pub type SpatialVector = Vec3;
A vector with a dimension equal to the maximum number of degrees of freedom of a rigid body.

Aliased Type

#[repr(C)]
pub struct SpatialVector { pub x: f32, pub y: f32, pub z: f32, }

Fields

x: f32y: f32z: f32