pub trait VectorExt: Sized + Copy {
// Required methods
fn ith(i: usize, val: f32) -> Self;
fn angle(self, other: Self) -> f32;
fn kronecker(self, other: Self) -> Matrix;
fn vget(&self, i: usize) -> f32;
fn vset(&mut self, i: usize, val: f32);
}Expand description
Extension trait for glam vector types to provide additional functionality.
Required Methods
Sourcefn ith(i: usize, val: f32) -> Self
fn ith(i: usize, val: f32) -> Self
Creates a vector with the i-th component set to val and all others to zero.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".